@@ -61,8 +61,7 @@ class CortxJupyter(ContentsManager):
 
         @gen.coroutine
         def dir_exists_async():
-            c = yield self._config()
-            return (yield _check_directory_exists(c, path))
+            return (yield _check_directory_exists(self._config(), path))
 
         return _run_sync(dir_exists_async)
 
@@ -70,8 +69,7 @@ class CortxJupyter(ContentsManager):
 
         @gen.coroutine
         def file_exists_async():
-            c = yield self._config()
-            return (yield _check_file_exists(c, path))
+            return (yield _check_file_exists(self._config(), path))
 
         return _run_sync(file_exists_async)
 
@@ -80,90 +78,61 @@ class CortxJupyter(ContentsManager):
         print(path,content,type,format)
         @gen.coroutine
         def get_async():
-            c = yield self._config()
-            return (yield _get_model(c, path, content, type, format))
+            return (yield _get_model(self._config(), path, content, type, format))
 
         return _run_sync(get_async)
 
     @gen.coroutine
     def save(self, model, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _save_model(c, model, path))
+            return (yield _save_model(self._config(), model, path))
 
     @gen.coroutine
     def delete(self, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            yield _delete_notebook(c, path)
+            yield _delete_notebook(self._config(), path)
 
     @gen.coroutine
     def update(self, model, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _rename_notebook(c, path, model['path']))
+            return (yield _rename_notebook(self._config(), path, model['path']))
 
     @gen.coroutine
     def new_untitled(self, path='', type='', ext=''):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _new_untitled_notebook(c, path, type, ext))
+            return (yield _new_untitled_notebook(self._config(), path, type, ext))
 
     @gen.coroutine
     def new(self, model, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _get_new_notebook(c, model, path))
+            return (yield _get_new_notebook(self._config(), model, path))
 
     @gen.coroutine
     def copy(self, from_path, to_path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _copy_notebook(c, from_path, to_path))
+            return (yield _copy_notebook(self._config(), from_path, to_path))
 
     @gen.coroutine
     def create_checkpoint(self, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _create_new_checkpoint(c, path))
+            return (yield _create_new_checkpoint(self._config(), path))
 
     @gen.coroutine
     def restore_checkpoint(self, checkpoint_id, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _restore_notebook_checkpoint(c, checkpoint_id, path))
+            return (yield _restore_notebook_checkpoint(self._config(), checkpoint_id, path))
 
     @gen.coroutine
     def list_checkpoints(self, path):
-        c = yield self._config()
-        return (yield _list_all_checkpoints(c, path))
+        return (yield _list_all_checkpoints(self._config(), path))
 
     @gen.coroutine
     def delete_checkpoint(self, checkpoint_id, path):
         with (yield self.write_lock.acquire()):
-            c = yield self._config()
-            return (yield _delete_notebook_checkpoint(c, checkpoint_id, path))
+            return (yield _delete_notebook_checkpoint(self._config(), checkpoint_id, path))
 
-    @gen.coroutine
     def _config(self):
-        authenticator = yield self.authentication.get_credentials()
-        creds = {
-            "region_name":self.region_name,
-            "bucket_name":self.bucket_name,
-            "host_name":self.host_name,
-            "cortx_authenticator":authenticator._asdict(),
-            "prefix":self.prefix,
-            "endpoint_url":self.endpoint_url
-        }
-
-        with open('credentials.json',"w") as fp:
-            json.dump(creds,fp)
-
-
-        print(json.load(open("credentials.json","r")))
-        # with open('credentials.json',"r") as fp):
-        #     print(json.load(fp))
-
+        
         return Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
